@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.3.2';
+our $VERSION = 'v2.3.3';
 
 use Narada::Config qw( get_config_line );
 use Log::Fast;
@@ -64,7 +64,12 @@ Narada::Log - setup project log
 
 =head1 VERSION
 
-This document describes Narada::Log version v2.3.2    use Narada::Log qw( $LOG );
+This document describes Narada::Log version v2.3.3
+
+
+=head1 SYNOPSIS
+
+    use Narada::Log qw( $LOG );
 
     $LOG->INFO("ready to work");
 
@@ -163,4 +168,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=cut
\ No newline at end of file
+=cut
